/******************************************************************************

Flex_Sensor_Tactile_Display_Combined
By Nick Gonyea
Code derived from SparkFun's Flex_Sensor_Example.ino 
(Jim Linblom; April 28, 2016)
 

Create a voltage divider circuit combining a flex sensor with a 10k resistor.
- The resistor should connect from A0 to GND.
- The flex sensor should connect from A0 to 3.3V
As the resistance of the flex sensor increases (meaning it's being bent), the
voltage at A0 should decrease.

******************************************************************************/
// measure the voltage at 3.3V and the actual resistance of your
// 10k resistor, and enter them below:

const float VCC = 3.33; // measured voltage of Ardunio 3.3V line
const float R_DIV = 10000.0; // measured 10k resistor


// upload the code, then try to adjust these values to more
// accurately calculate bend degree.
float STRAIGHT_RESISTANCE = 60000.0; // measured straight resistance
float BEND_RESISTANCE = 90000.0; // resistance at 90 deg


// allocate a digital port for the motor
int mtr = 5;


void setup() 
{
  pinMode(A0, INPUT);
  pinMode(5, OUTPUT);
  
  Serial.begin(115200);
}

void loop() 
{
    // Read the ADC, and calculate voltage and resistance from it
    int flexADC = analogRead(0);
    float flexV = flexADC * VCC / 1023.0;
    float flexR = R_DIV * (VCC / flexV - 1.0);
    Serial.println("Resistance: " + String(flexR) + " ohms");
    Serial.println();
    Serial.println("-------------------------");
    Serial.println();
      
    
    float angle = map(flexR, STRAIGHT_RESISTANCE, BEND_RESISTANCE, 0.0, 90.0);
    Serial.println("Bend: " + String(angle) + " degrees");
    Serial.println();
    Serial.println("-------------------------");
    Serial.println();

    float FWD_intensity = map(angle, 5.0, 80.0, 30.0, 130.0);
    Serial.println("Forward Intensity: " + String(FWD_intensity));
    Serial.println();
    Serial.println("-------------------------");
    Serial.println();
    Serial.println();
    Serial.println();
    Serial.println();
    Serial.println();

    
      if (angle > 5.0){
        analogWrite(mtr, FWD_intensity);
      }
      
      else{
        analogWrite(mtr, 0);
      }


      
    delay(500);
}

